pydeseq2.grid\_search
=====================

.. automodule:: pydeseq2.grid_search







   .. rubric:: Functions

   .. autosummary::

      grid_fit_alpha
      grid_fit_beta
      grid_fit_shrink_beta
      vec_nb_nll
